aboutsummaryrefslogtreecommitdiffstats
path: root/lib/offline-support.js
diff options
context:
space:
mode:
authorMatěj Cepl <mcepl@redhat.com>2010-07-14 12:28:09 +0200
committerMatěj Cepl <mcepl@redhat.com>2010-07-14 16:44:25 +0200
commit97123f05a19a1cbec41ef4b7b72adf0c3f681113 (patch)
treeb6795a046b6f374f91e60ba616aa921d5c6ad107 /lib/offline-support.js
parent890a07ac1cfa6b60d450909a0108750db58fbbaa (diff)
downloadbugzilla-triage-97123f05a19a1cbec41ef4b7b72adf0c3f681113.tar.gz
make fix
- check for occurrence of FIXME in all lib/*.js files. - clear out obsolete ones - add fix target as dependency of all one.
Diffstat (limited to 'lib/offline-support.js')
-rw-r--r--lib/offline-support.js10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/offline-support.js b/lib/offline-support.js
index e823069..e0b1c3b 100644
--- a/lib/offline-support.js
+++ b/lib/offline-support.js
@@ -7,7 +7,7 @@
/* Offline supporting functions */
/**
*
- * @todo FIXME this probably makes a closure and a memory leak name='changeform'
+ * @todo TODO this probably makes a closure and a memory leak name='changeform'
* investigate
* https://developer.mozilla.org/en/How_to_Turn_Off_Form_Autocompletion
*
@@ -71,7 +71,7 @@ RHBugzillaPage.prototype.serializeForm = function(form) {
serialForm.dataOut = Array.filter(form.elements,function(el) {
return !el.disabled && el.name &&
// FIXME shouldn't I just add && el.value here?
(el.checked || /select|textarea/i.test(el.nodeName) ||
/text|hidden|password|search/i.test(el.type));
}).map(serializeControl).join("&");
@@ -102,7 +102,7 @@ RHBugzillaPage.prototype.serializeForm = function(form) {
*/
/*function onlineCallback() {
function deserializeAndSend(formData) {
- // FIXME notImplemented
+ // TODO notImplemented
// is it enough to just
// run XMLHttpRequest? Probably yes, this is just a form
// and this is just a HTTP request
@@ -116,12 +116,12 @@ RHBugzillaPage.prototype.serializeForm = function(form) {
// this seems to be also interesting
// https://developer.mozilla.org/en/Code_snippets/Post_data_to_window
console.error("Sending bugs not implemented yet!");
- return ""; // FIXME check other HTTP headers to be set
+ return ""; // TODO check other HTTP headers to be set
var bugID = formData.bugNo;
var req = new XMLHttpRequest();
req.open("POST", formData.action, true);
- // FIXME co očekávám za odpověď? req.overrideMimeType("text/xml");
+ // TODO co očekávám za odpověď? req.overrideMimeType("text/xml");
// * Accept-Encoding
// * Accept-Language
// * Accept (MIME types)
@@ -71,7 +71,7 @@ RHBugzillaPage.prototype.serializeForm = function(form) {
serialForm.dataOut = Array.filter(form.elements,function(el) {
return !el.disabled && el.name &&
- // FIXME shouldn't I just add && el.value here?
+ // TODO shouldn't I just add && el.value here?
(el.checked || /select|textarea/i.test(el.nodeName) ||
/text|hidden|password|search/i.test(el.type));